@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import sys
+import re
 sys.path += [ "../.."]
 from PyQt4 import QtCore, QtGui
 from boadata.trees.file import DirectoryTree
@@ -11,7 +12,7 @@ def run_app():
     
     if len(sys.argv) > 1:
         path = sys.argv[1]
-        if path.startswith("mysql://"):
+        if re.search("sql.*://", path):
             node = DatabaseTree(path)
         else:
             node = DirectoryTree(path)
